@@ -24,7 +24,7 @@ def get_oss_path(contract_number):
     num = int(contract_number.split("-")[1][1:])
     floor = str(math.floor(num/100) * 100 + 1).zfill(4)
     ceil = str(math.ceil(num/100) * 100).zfill(4)
-    oss_path = "bos://seqhealth/%s/%s-%s/%s/Data/"%(year, floor, ceil, contract_number)
+    oss_path = "/%s/%s-%s/%s/Data/"%(year, floor, ceil, contract_number)
     return oss_path
 
 class Geo_common:
@@ -144,7 +144,7 @@ fi
         report_shell = os.path.join(self.pro_dir, "report.sh")
         with open(report_shell,'w') as f:
             f.write("""
-%s/script/SuppGenerate.py --yaml %s --odir %s/Report/supp && \\
+%s/script/SuppGenerate.py --yaml %s --odir %s/Report/supp/ && \\
 
 %s/script/Report.R %s %s/Report
 """%(self.pro_dir, yaml_file, self.pro_dir,
@@ -154,25 +154,30 @@ fi
         oss_path = get_oss_path(self.contract_number)
         msn = "hello, %s 的 上传已完成，路径为 %s ."%(self.contract_number, oss_path)
         talk = ding_talk(msn, self.analyst_phone_number)
+        fail_msn = "hello, %s 的 上传失败! 路径为 %s ."%(self.contract_number, oss_path)
+        fail_talk = ding_talk(fail_msn, self.analyst_phone_number)
         with open(upload_shell,"w") as f:
             f.write("""
 cd %s
 
-%s/script/DataRelease.py --yaml %s --odir Upload/ && \\
+%s/script/DataRelease.py --yaml %s --odir %s/Upload/ && \\
 
-tree Upload > %s_tree.txt && \\
+python3 -m excelParse.upload -i %s/Uplaod/ -o %s 
 
-tar -chvf %s_release.tar Upload/ && \\
+if [ $? -eq 0 ];
+then
+    #DingTalk
+    %s
+else
+    #Fail DingTalk
+    %s
+fi
 
-bcecmd bos cp %s_tree.txt %s && bcecmd bos cp %s_release.tar %s && \\
-    
-%s
 """ %(self.pro_dir,
-      self.pipe_dir, yaml_file, 
-      self.contract_number, 
-      self.contract_number, 
-      self.contract_number, oss_path, self.contract_number, oss_path,
-      talk))
+      self.pipe_dir, yaml_file, self.pro_dir,
+      self.pro_dir , oss_path,
+      talk,
+      fail_talk))
 
         # 打印运行命令
         msn = "\n\033[34m%s\033[0m 的shell脚本已生成。shell脚本路径为: \033[34m%s\033[0m .\n\n您可以选择运行以下命令：\n%s"%(self.contract_number, self.pro_dir , "\n".join(shells))
